
# Slot: description


text of an attributed description

URI: [linkml:alt_description_text](https://w3id.org/linkml/alt_description_text)


## Domain and Range

[AltDescription](AltDescription.md) &#8594;  <sub>1..1</sub> [String](String.md)

## Parents


## Children


## Used by

 * [AltDescription](AltDescription.md)
